==> zio-aws-redshift_3-5.17.121.2-sources.jar: zio/aws/redshift/model/ModifyAquaConfigurationResponse.scala <==
package zio.aws.redshift.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class ModifyAquaConfigurationResponse(
    aquaConfiguration: Option[zio.aws.redshift.model.AquaConfiguration] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.redshift.model.ModifyAquaConfigurationResponse = {
    import ModifyAquaConfigurationResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.redshift.model.ModifyAquaConfigurationResponse
      .builder()
      .optionallyWith(aquaConfiguration.map(value => value.buildAwsValue()))(
        _.aquaConfiguration
      )
      .build()
  }
  def asReadOnly
      : zio.aws.redshift.model.ModifyAquaConfigurationResponse.ReadOnly =
    zio.aws.redshift.model.ModifyAquaConfigurationResponse.wrap(buildAwsValue())
}
object ModifyAquaConfigurationResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.redshift.model.ModifyAquaConfigurationResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.redshift.model.ModifyAquaConfigurationResponse =
      zio.aws.redshift.model.ModifyAquaConfigurationResponse(
        aquaConfiguration.map(value => value.asEditable)
      )
    def aquaConfiguration
        : Option[zio.aws.redshift.model.AquaConfiguration.ReadOnly]
    def getAquaConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.redshift.model.AquaConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField("aquaConfiguration", aquaConfiguration)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.redshift.model.ModifyAquaConfigurationResponse
  ) extends zio.aws.redshift.model.ModifyAquaConfigurationResponse.ReadOnly {
    override val aquaConfiguration
        : Option[zio.aws.redshift.model.AquaConfiguration.ReadOnly] = scala
      .Option(impl.aquaConfiguration())
      .map(value => zio.aws.redshift.model.AquaConfiguration.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.redshift.model.ModifyAquaConfigurationResponse
  ): zio.aws.redshift.model.ModifyAquaConfigurationResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-redshift_3-5.17.197.2-sources.jar: zio/aws/redshift/model/ModifyAquaConfigurationResponse.scala <==
package zio.aws.redshift.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class ModifyAquaConfigurationResponse(
    aquaConfiguration: Optional[zio.aws.redshift.model.AquaConfiguration] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.redshift.model.ModifyAquaConfigurationResponse = {
    import ModifyAquaConfigurationResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.redshift.model.ModifyAquaConfigurationResponse
      .builder()
      .optionallyWith(aquaConfiguration.map(value => value.buildAwsValue()))(
        _.aquaConfiguration
      )
      .build()
  }
  def asReadOnly
      : zio.aws.redshift.model.ModifyAquaConfigurationResponse.ReadOnly =
    zio.aws.redshift.model.ModifyAquaConfigurationResponse.wrap(buildAwsValue())
}
object ModifyAquaConfigurationResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.redshift.model.ModifyAquaConfigurationResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.redshift.model.ModifyAquaConfigurationResponse =
      zio.aws.redshift.model.ModifyAquaConfigurationResponse(
        aquaConfiguration.map(value => value.asEditable)
      )
    def aquaConfiguration
        : Optional[zio.aws.redshift.model.AquaConfiguration.ReadOnly]
    def getAquaConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.redshift.model.AquaConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField("aquaConfiguration", aquaConfiguration)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.redshift.model.ModifyAquaConfigurationResponse
  ) extends zio.aws.redshift.model.ModifyAquaConfigurationResponse.ReadOnly {
    override val aquaConfiguration
        : Optional[zio.aws.redshift.model.AquaConfiguration.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.aquaConfiguration())
        .map(value => zio.aws.redshift.model.AquaConfiguration.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.redshift.model.ModifyAquaConfigurationResponse
  ): zio.aws.redshift.model.ModifyAquaConfigurationResponse.ReadOnly =
    new Wrapper(impl)
}
